@@ -2,4 +2,6 @@ import EspyBase
 import PythonCheck
 import PythonLibraryCheck
 import ExternalCheck
-VERSION = "0.1.0"
\ No newline at end of file
+import GemCheck
+import NpmCheck
+VERSION = "0.2.0"
\ No newline at end of file
